--#Copyright (C) 2006 - 2009 NTT DATA Corporation--#
--#This program is free software; you can redistribute it and/or
--#Modify it under the terms of the GNU General Public License
--#as published by the Free Software Foundation, version 2.
--#
--#This program is distributed in the hope that it will be useful,
--#but WITHOUT ANY WARRANTY; without even the implied warranty of
--#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--#GNU General Public License for more details

begin;

--# select a set of session_id to be deleted.

SELECT session_id  INTO TEMPORARY cc_job_completed_sessions
    FROM cc_job_session_job 
        WHERE (status='300' OR status='301') AND (job_id, session_id ) IN (select job_id,session_id FROM cc_job_session);

--# execute 

DELETE FROM cc_job_session WHERE session_id IN (select session_id from cc_job_completed_sessions);

DELETE FROM cc_notify_relation_info
    WHERE ( notify_group_id ) like any (
        select DISTINCT 'JOB_SES-' || session_id || '%' from cc_job_completed_sessions
    );
DELETE FROM cc_action_inhibition_info
    WHERE ( notify_group_id ) like any (
        select DISTINCT 'JOB_SES-' || session_id || '%' from cc_job_completed_sessions
    );

commit;
